==> openGion7.2.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE70S.sql <==
/****************************************************************************/
/* GE70 ( 取込要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GE70 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*   1 ｼｽﾃﾑID               */
 , RSRV_NO          INTEGER                                     NOT NULL            /*   2 予約番号             */
 , NAME_JA          varchar           (  200 )                                      /*   3 名称                 */
 , EXECID           varchar           (   20 )                  NOT NULL            /*   4 処理ID               */
 , FGYKAN           varchar           (    1 )      DEFAULT '2' NOT NULL            /*   5 取込予約ﾌﾗｸﾞ         */
 , DIR_BASE         varchar           (  200 )                                      /*   6 取込ﾍﾞｰｽﾌｫﾙﾀﾞ        */
 , DIR_SUB          varchar           (  200 )                                      /*   7 取込ｻﾌﾞﾌｫﾙﾀﾞ         */
 , DIR_WORK         varchar           (  200 )                                      /*   8 処理ﾌｫﾙﾀﾞ(WORK)      */
 , DIR_BKUP_OK      varchar           (  200 )                                      /*   9 処理済ﾌｫﾙﾀﾞ(正常)    */
 , DIR_BKUP_NG      varchar           (  200 )                                      /*  10 処理済ﾌｫﾙﾀﾞ(異常)    */
 , FILE_FILTER      varchar           ( 4000 )                                      /*  11 検索条件             */
 , RELEASE_NOTES    varchar           (  120 )                                      /*  12 ﾘﾘｰｽﾉｰﾄ              */
 , RDC_CODE         varchar           (   20 )                                      /*  13 設変番号             */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時             */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG               */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG             */
 , USRSET           varchar           (   10 )                                      /* 850 作成者               */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時             */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG               */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG             */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者               */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GE70S.sql <==
/****************************************************************************/
/* GE70 ( 取込要求ﾃｰﾌﾞﾙ )                                                   */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GE70 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*   1 ｼｽﾃﾑID               */
 , RSRV_NO          INTEGER                                     NOT NULL            /*   2 予約番号             */
 , NAME_JA          varchar           (  200 )                                      /*   3 名称                 */
 , EXECID           varchar           (   20 )                  NOT NULL            /*   4 処理ID               */
 , FGYKAN           varchar           (    1 )      DEFAULT '2' NOT NULL            /*   5 取込予約ﾌﾗｸﾞ         */
 , DIR_BASE         varchar           (  200 )                                      /*   6 取込ﾍﾞｰｽﾌｫﾙﾀﾞ        */
 , DIR_SUB          varchar           (  200 )                                      /*   7 取込ｻﾌﾞﾌｫﾙﾀﾞ         */
 , DIR_WORK         varchar           (  200 )                                      /*   8 処理ﾌｫﾙﾀﾞ(WORK)      */
 , DIR_BKUP_OK      varchar           (  200 )                                      /*   9 処理済ﾌｫﾙﾀﾞ(正常)    */
 , DIR_BKUP_NG      varchar           (  200 )                                      /*  10 処理済ﾌｫﾙﾀﾞ(異常)    */
 , FILE_FILTER      varchar           ( 4000 )                                      /*  11 検索条件             */
 , RELEASE_NOTES    varchar           (  120 )                                      /*  12 ﾘﾘｰｽﾉｰﾄ              */
 , RDC_CODE         varchar           (   20 )                                      /*  13 設変番号             */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ               */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ             */
 , DYSET            varchar           (   14 )                                      /* 820 作成日時             */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG               */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG             */
 , USRSET           varchar           (   10 )                                      /* 850 作成者               */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時             */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG               */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG             */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者               */
);
